@@ -18,7 +18,6 @@ from twisted.internet import reactor
 from twisted.python import log as tlog
 from struct import pack
 from hashlib import sha1
-from mysql.connector import connect as mysqlconnect
 from subprocess import Popen
 from os import path
 from honeypots.helper import close_port_wrapper, get_free_port, kill_server_wrapper, server_arguments, setup_logger, disable_logger, set_local_vars, check_if_server_is_running
@@ -124,13 +123,13 @@ class QMysqlServer():
                         return string.decode('utf-8', 'ignore')
                     else:
                         return str(string)
-                except Exception as e:
+                except Exception:
                     return string
 
             def connectionMade(self):
                 self._state = 1
                 self.transport.write(_q_s.greeting())
-                _q_s.logs.info(['servers', {'server': 'mysql_server', 'action': 'connection', 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port}])
+                _q_s.logs.info({'server': 'mysql_server', 'action': 'connection', 'src_ip': self.transport.getPeer().host, 'src_port': self.transport.getPeer().port})
 
             def dataReceived(self, data):
                 try:
@@ -151,7 +150,7 @@ class QMysqlServer():
                             else:
                                 ret_access_denied = True
                                 password = ':'.join(hex((c))[2:] for c in data)
-                        _q_s.logs.info(['servers', {'server': 'mysql_server', 'action': 'login', 'status': status, 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port, 'username': username, 'password': password}])
+                        _q_s.logs.info({'server': 'mysql_server', 'action': 'login', 'status': status, 'src_ip': self.transport.getPeer().host, 'src_port': self.transport.getPeer().port, 'username': username, 'password': password})
 
                         if ret_access_denied:
                             self.transport.write(_q_s.access_denied())
@@ -159,7 +158,7 @@ class QMysqlServer():
                             self.transport.write(_q_s.too_many())
                     else:
                         self.transport.loseConnection()
-                except BaseException as e:
+                except BaseException:
                     self.transport.write(_q_s.too_many())
                     self.transport.loseConnection()
 
@@ -188,7 +187,7 @@ class QMysqlServer():
                 if self.process.poll() is None and check_if_server_is_running(self.uuid):
                     status = 'success'
 
-            self.logs.info(['servers', {'server': 'mysql_server', 'action': 'process', 'status': status, 'ip': self.ip, 'port': self.port, 'username': self.username, 'password': self.password}])
+            self.logs.info({'server': 'mysql_server', 'action': 'process', 'status': status, 'src_ip': self.ip, 'src_port': self.port, 'username': self.username, 'password': self.password})
 
             if status == 'success':
                 return True
@@ -198,16 +197,6 @@ class QMysqlServer():
         else:
             self.mysql_server_main()
 
-    def test_server(self, ip=None, port=None, username=None, password=None):
-        try:
-            _ip = ip or self.ip
-            _port = port or self.port
-            _username = username or self.username
-            _password = password or self.password
-            cnx = mysqlconnect(user=_username, password=_password, host=_ip, port=_port, database='test', connect_timeout=1000)
-        except Exception as e:
-            pass
-
     def close_port(self):
         ret = close_port_wrapper('mysql_server', self.ip, self.port, self.logs)
         return ret
@@ -216,6 +205,17 @@ class QMysqlServer():
         ret = kill_server_wrapper('mysql_server', self.uuid, self.process)
         return ret
 
+    def test_server(self, ip=None, port=None, username=None, password=None):
+        try:
+            from mysql.connector import connect as mysqlconnect
+            _ip = ip or self.ip
+            _port = port or self.port
+            _username = username or self.username
+            _password = password or self.password
+            cnx = mysqlconnect(user=_username, password=_password, host=_ip, port=_port, database='test', connect_timeout=1000)
+        except Exception as e:
+            pass
+
 
 if __name__ == '__main__':
     parsed = server_arguments()
