@@ -13,15 +13,13 @@
 from warnings import filterwarnings
 filterwarnings(action='ignore', module='.*OpenSSL.*')
 
-from twisted.internet.protocol import Protocol, Factory, DatagramProtocol
+from twisted.internet.protocol import DatagramProtocol
 from twisted.internet import reactor
 from struct import unpack, calcsize, pack
 from time import time
 from twisted.python import log as tlog
 from subprocess import Popen
-from psycopg2 import connect
 from os import path
-from socket import socket, AF_INET, SOCK_DGRAM
 from honeypots.helper import close_port_wrapper, get_free_port, kill_server_wrapper, server_arguments, setup_logger, disable_logger, set_local_vars, check_if_server_is_running
 from uuid import uuid4
 
@@ -67,7 +65,7 @@ class QNTPServer():
                 mode = 'UnKnown'
                 success = False
                 unpacked = None
-                _q_s.logs.info(['servers', {'server': 'ntp_server', 'action': 'connection', 'ip': addr[0], 'port': addr[1]}])
+                _q_s.logs.info({'server': 'ntp_server', 'action': 'connection', 'src_ip': addr[0], 'src_port': addr[1]})
                 if len(data) == calcsize('!B B B b I I I Q Q Q Q'):
                     version = data[0] >> 3 & 0x7
                     mode = data[0] & 0x7
@@ -79,9 +77,9 @@ class QNTPServer():
                         success = True
 
                 if success:
-                    _q_s.logs.info(['servers', {'server': 'ntp_server', 'action': 'query', 'status': 'success', 'ip': addr[0], 'port': addr[1], 'version': version, 'mode': mode}])
+                    _q_s.logs.info({'server': 'ntp_server', 'action': 'query', 'status': 'success', 'src_ip': addr[0], 'src_port': addr[1], 'dst_ip': _q_s.ip, 'dst_port': _q_s.port, 'version': version, 'mode': mode})
                 else:
-                    _q_s.logs.info(['servers', {'server': 'ntp_server', 'action': 'query', 'status': 'fail', 'ip': addr[0], 'port': addr[1], 'version': version, 'mode': mode}])
+                    _q_s.logs.info({'server': 'ntp_server', 'action': 'query', 'status': 'fail', 'src_ip': addr[0], 'src_port': addr[1], 'dst_ip': _q_s.ip, 'dst_port': _q_s.port, 'version': version, 'mode': mode})
 
                 self.transport.loseConnection()
 
@@ -105,7 +103,7 @@ class QNTPServer():
                 if self.process.poll() is None and check_if_server_is_running(self.uuid):
                     status = 'success'
 
-            self.logs.info(['servers', {'server': 'ntp_server', 'action': 'process', 'status': status, 'ip': self.ip, 'port': self.port}])
+            self.logs.info({'server': 'ntp_server', 'action': 'process', 'status': status, 'src_ip': self.ip, 'src_port': self.port})
 
             if status == 'success':
                 return True
@@ -115,8 +113,17 @@ class QNTPServer():
         else:
             self.ntp_server_main()
 
+    def close_port(self):
+        ret = close_port_wrapper('ntp_server', self.ip, self.port, self.logs)
+        return ret
+
+    def kill_server(self):
+        ret = kill_server_wrapper('ntp_server', self.uuid, self.process)
+        return ret
+
     def test_server(self, ip=None, port=None, username=None, password=None):
         try:
+            from socket import socket, AF_INET, SOCK_DGRAM
             _ip = ip or self.ip
             _port = port or self.port
             c = socket(AF_INET, SOCK_DGRAM)
@@ -126,14 +133,6 @@ class QNTPServer():
         except BaseException:
             pass
 
-    def close_port(self):
-        ret = close_port_wrapper('ntp_server', self.ip, self.port, self.logs)
-        return ret
-
-    def kill_server(self):
-        ret = kill_server_wrapper('ntp_server', self.uuid, self.process)
-        return ret
-
 
 if __name__ == '__main__':
     parsed = server_arguments()
