@@ -17,7 +17,6 @@ from twisted.mail.pop3 import POP3
 from twisted.internet.protocol import Factory
 from twisted.internet import reactor
 from random import choice
-from poplib import POP3 as poplibPOP3
 from twisted.python import log as tlog
 from subprocess import Popen
 from os import path
@@ -62,7 +61,7 @@ class QPOP3Server():
                     return str(string)
 
             def connectionMade(self):
-                _q_s.logs.info(['servers', {'server': 'pop3_server', 'action': 'connection', 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port}])
+                _q_s.logs.info({'server': 'pop3_server', 'action': 'connection', 'src_ip': self.transport.getPeer().host, 'src_port': self.transport.getPeer().port, 'dst_ip': _q_s.ip, 'dst_port': _q_s.port})
                 self._user = None
                 if isinstance(_q_s.mocking, bool):
                     if _q_s.mocking == True:
@@ -85,7 +84,7 @@ class QPOP3Server():
                         username = _q_s.username
                         password = _q_s.password
                         status = 'success'
-                    _q_s.logs.info(['servers', {'server': 'pop3_server', 'action': 'login', 'status': status, 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port, 'username': username, 'password': password}])
+                    _q_s.logs.info({'server': 'pop3_server', 'action': 'login', 'status': status, 'src_ip': self.transport.getPeer().host, 'src_port': self.transport.getPeer().port, 'dst_ip': _q_s.ip, 'dst_port': _q_s.port, 'username': username, 'password': password})
                     self.failResponse('Authentication failed')
                 else:
                     self.failResponse('USER first, then PASS')
@@ -129,7 +128,7 @@ class QPOP3Server():
                 if self.process.poll() is None and check_if_server_is_running(self.uuid):
                     status = 'success'
 
-            self.logs.info(['servers', {'server': 'pop3_server', 'action': 'process', 'status': status, 'ip': self.ip, 'port': self.port, 'username': self.username, 'password': self.password}])
+            self.logs.info({'server': 'pop3_server', 'action': 'process', 'status': status, 'src_ip': self.ip, 'src_port': self.port, 'username': self.username, 'password': self.password})
 
             if status == 'success':
                 return True
@@ -139,8 +138,17 @@ class QPOP3Server():
         else:
             self.pop3_server_main()
 
+    def close_port(self):
+        ret = close_port_wrapper('pop3_server', self.ip, self.port, self.logs)
+        return ret
+
+    def kill_server(self):
+        ret = kill_server_wrapper('pop3_server', self.uuid, self.process)
+        return ret
+
     def test_server(self, ip=None, port=None, username=None, password=None):
         try:
+            from poplib import POP3 as poplibPOP3
             _ip = ip or self.ip
             _port = port or self.port
             _username = username or self.username
@@ -151,14 +159,6 @@ class QPOP3Server():
         except BaseException:
             pass
 
-    def close_port(self):
-        ret = close_port_wrapper('pop3_server', self.ip, self.port, self.logs)
-        return ret
-
-    def kill_server(self):
-        ret = kill_server_wrapper('pop3_server', self.uuid, self.process)
-        return ret
-
 
 if __name__ == '__main__':
     parsed = server_arguments()
